@@ -481,5 +481,90 @@ DEFAULT_DEFINITIONS = [
             {'field': 'dxmccs24', 'type': 'VARCHAR'},
             {'field': 'dxmccs25', 'type': 'VARCHAR'}
         ]
+    },
+    # Long table (lookup table) definitions follow.    
+    # If I had more time, these would be drawn from PyHCUP.
+    # But their definition in PyHCUP would require a non-
+    # trivial amount of reworking to get into a portable
+    # format.
+    # Alas!
+    {
+        'name': 'SID Charges (long)',
+        'category': 'CHARGES',
+        'ds_family_abbr': 'SID', 
+        'ds_parent_abbr': 'HCUP', # the parent of the real Definition.data_source
+        'columns': [
+            {'field': 'KEY', 'type': 'BIGINT'},
+            {'field': 'VISITLINK', 'type': 'BIGINT'},
+            {'field': 'DAYSTOEVENT', 'type': 'INT'},
+            {'field': 'YEAR', 'type': 'INT'},
+            {'field': 'STATE', 'type': 'VARCHAR'},
+            {'field': 'UNITS', 'type': 'INT'},
+            {'field': 'REVCODE', 'type': 'VARCHAR'},
+            {'field': 'RATE', 'type': 'NUMERIC(16, 2)'},
+            {'field': 'CHARGE', 'type': 'NUMERIC(16, 2)'},
+            {'field': 'CPTHCPCS', 'type': 'VARCHAR'},
+            {'field': 'CPTMOD1', 'type': 'VARCHAR'},
+            {'field': 'CPTMOD2', 'type': 'VARCHAR'},
+            {'field': 'GROUP_NUMBER', 'type': 'INT'}
+        ]
+    },
+    {
+        'name': 'SID Diagnoses (long)',
+        'category': 'DX',
+        'ds_family_abbr': 'SID', 
+        'ds_parent_abbr': 'HCUP', # the parent of the real Definition.data_source
+        'columns': [
+            {'field': 'KEY', 'type': 'BIGINT'},
+            {'field': 'VISITLINK', 'type': 'BIGINT'},
+            {'field': 'DAYSTOEVENT', 'type': 'INT'},
+            {'field': 'YEAR', 'type': 'INT'},
+            {'field': 'STATE', 'type': 'VARCHAR'},
+            {'field': 'DX', 'type': 'VARCHAR'},
+            {'field': 'DXV', 'type': 'VARCHAR'},
+            {'field': 'DXCCS', 'type': 'VARCHAR'},
+            {'field': 'DXPOA', 'type': 'VARCHAR'},
+            {'field': 'DXatAdmit', 'type': 'VARCHAR'},
+            {'field': 'TMDX', 'type': 'VARCHAR'},
+            {'field': 'GROUP_NUMBER', 'type': 'INT'}
+        ]
+    },
+    {
+        'name': 'SID Procedures (long)',
+        'category': 'PR',
+        'ds_family_abbr': 'SID', 
+        'ds_parent_abbr': 'HCUP', # the parent of the real Definition.data_source
+        'columns': [
+            {'field': 'KEY', 'type': 'BIGINT'},
+            {'field': 'VISITLINK', 'type': 'BIGINT'},
+            {'field': 'DAYSTOEVENT', 'type': 'INT'},
+            {'field': 'YEAR', 'type': 'INT'},
+            {'field': 'STATE', 'type': 'VARCHAR'},
+            {'field': 'PR', 'type': 'VARCHAR'},
+            {'field': 'PRCCS', 'type': 'VARCHAR'},
+            {'field': 'PRDATE', 'type': 'VARCHAR'},
+            {'field': 'PRDAY', 'type': 'VARCHAR'},
+            {'field': 'PRMONTH', 'type': 'VARCHAR'},
+            {'field': 'PRYEAR', 'type': 'VARCHAR'},
+            {'field': 'PRV', 'type': 'VARCHAR'},
+            {'field': 'PCLASS', 'type': 'VARCHAR'},
+            {'field': 'PRMCCS', 'type': 'VARCHAR'},
+            {'field': 'GROUP_NUMBER', 'type': 'INT'}
+        ]
+    },
+    {
+        'name': 'SID Utilization Flags (long)',
+        'category': 'UFLAGS',
+        'ds_family_abbr': 'SID', 
+        'ds_parent_abbr': 'HCUP', # the parent of the real Definition.data_source
+        'columns': [
+            {'field': 'KEY', 'type': 'BIGINT'},
+            {'field': 'VISITLINK', 'type': 'BIGINT'},
+            {'field': 'DAYSTOEVENT', 'type': 'INT'},
+            {'field': 'YEAR', 'type': 'INT'},
+            {'field': 'STATE', 'type': 'VARCHAR'},
+            {'field': 'NAME', 'type': 'VARCHAR'},
+            {'field': 'VALUE', 'type': 'INT'}
+        ]
     }
 ]
